from setuptools import setup

setup(
      name='probability_and_distributions',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['probability_and_distributions'],
      author='Wesley Jeng',
      zip_safe=False
)
